@@ -33,7 +33,15 @@ class Base(ABC):
             Metodo que se encarga de darle formato a la
             salida del procesamiento de la accion.
         """
-        errorCode = int(errorCode)
+
+        try:
+            errorCodeBk = errorCode
+            # Prevenir el paso de string como error
+            errorCode = int(errorCode)
+        except:
+            print(
+                'Ocurrio une error al realizar el CAST del error code: {}'.format(errorCodeBk))
+            errorCode = -99
 
         # Regresar la respuesta con el formato correcto
         if not errorWorker is None:
