@@ -8,6 +8,7 @@ import base64
 import datetime
 import traceback
 import uuid
+import re
 import _thread
 import asyncio  # Requerido
 from jaeger_client import Config
@@ -595,8 +596,11 @@ class Microservices(BaseClass, ABC):
             TOPIC_RESP = TOPIC_RESP if TOPIC_RESP else "respuesta_{}".format(
                 dataResponse['metadata']['owner'])
         else:
+            # Comprobar si corresponde a un topico de servicio o sistema
+            is_topic = re.search(
+                "[a-zA-Z0-9]{1,}[_.]{1}[a-zA-Z0-9]{1,}[_.]{1}.*", TOPIC_RESP)
             # Asignar el id de ruta que proviene del reply
-            TOPIC_RESP = TOPIC_RESP if TOPIC_RESP else nats_route
+            TOPIC_RESP = TOPIC_RESP if is_topic else nats_route
 
         # Consultar quien es el callback
         cllb = getItemBy('metadata.callback', dataResponse)
